<?php

declare(strict_types=1);

namespace DigiComp\FluidCurrentControllerExpression\Tests\Functional;

use Neos\Flow\Mvc\Routing\Route;
use Neos\Flow\Tests\FunctionalTestCase;

class CurrentControllerExpressionNodeTest extends FunctionalTestCase
{
    /**
     * Initializer
     */
    protected function setUp(): void
    {
        parent::setUp();

        $route = new Route();
        $route->setUriPattern('test/currentcontrollerexpressions/test(/{@action})');
        $route->setDefaults([
            '@package' => 'DigiComp.FluidCurrentControllerExpression',
            '@subpackage' => 'Tests\Functional\Fixtures',
            '@controller' => 'Test',
            '@action' => 'index',
        ]);
        $route->setAppendExceedingArguments(true);
        $this->router->addRoute($route);
    }

    /**
     * @test
     */
    public function itReturnsCurrentControllerInformations(): void
    {
        $response = $this->browser->request('http://localhost/test/currentcontrollerexpressions/test');
        static::assertEquals(
            'Test
index
DigiComp.FluidCurrentControllerExpression
Tests\Functional\Fixtures
DigiComp\FluidCurrentControllerExpression\Tests\Functional\Fixtures\Controller\TestController
html
',
            (string)$response->getBody()
        );
    }

    /**
     * @test
     */
    public function itReturnsCurrentControllerInformationsUsedInLayouts(): void
    {
        $response = $this->browser->request('http://localhost/test/currentcontrollerexpressions/test/withlayout');
        static::assertEquals(
            'Test
withLayout
DigiComp.FluidCurrentControllerExpression
Tests\Functional\Fixtures
DigiComp\FluidCurrentControllerExpression\Tests\Functional\Fixtures\Controller\TestController
html
',
            (string)$response->getBody()
        );
    }

    /**
     * @test
     */
    public function itReturnsCurrentControllerInformationsUsedInArrays(): void
    {
        $response = $this->browser->request('http://localhost/test/currentcontrollerexpressions/test/inArrays');
        static::assertEquals(
            'Test
inArrays
DigiComp.FluidCurrentControllerExpression
Tests\Functional\Fixtures
DigiComp\FluidCurrentControllerExpression\Tests\Functional\Fixtures\Controller\TestController
html
',
            (string)$response->getBody()
        );
    }
}
